sequencetools.CyclicTree
========================

.. abjad-lineage:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree

.. autoclass:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.children
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.depth
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.index_in_parent
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.level
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.negative_level
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.position
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.root
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.storage_format
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.width
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_next_n_complete_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_next_n_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_node_at_position
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.get_position_of_descendant
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.is_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.iterate_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.iterate_depth_first
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.iterate_payload
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.remove
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.remove_to_root
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.to_nested_lists
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__contains__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__eq__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__ge__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__getitem__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__gt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__iter__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__le__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__len__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__lt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__ne__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__repr__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTree.CyclicTree.CyclicTree.__str__
   :noindex:
